@@ -1,7 +1,10 @@
+import warnings
+
+import numpy as np
+from scipy.sparse.linalg import lsmr
+
 from .errors import EfficiencyWarning, NoSolutionFound
 from .lca import LCA
-from scipy.sparse.linalg import lsqr, lsmr
-import warnings
 
 
 class LeastSquaresLCA(LCA):
@@ -14,20 +17,20 @@ class LeastSquaresLCA(LCA):
     * `Another least-squares algorithm in SciPy <http://docs.scipy.org/doc/scipy/reference/generated/scipy.sparse.linalg.lsqr.html#scipy.sparse.linalg.lsqr>`_
 
     """
-    def solve_linear_system(self, solver=lsmr):
+
+    def load_lci_data(self) -> None:
+        super().load_lci_data(nonsquare_ok=True)
+
+    def solve_linear_system(self, solver=lsmr) -> np.ndarray:
         if self.technosphere_matrix.shape[0] == self.technosphere_matrix.shape[1]:
-            warnings.warn("Don't use LeastSquaresLCA for square matrices",
-                          EfficiencyWarning)
-        self.solver_results = solver(
-            self.technosphere_matrix,
-            self.demand_array
-        )
+            warnings.warn("Don't use LeastSquaresLCA for square matrices", EfficiencyWarning)
+        self.solver_results = solver(self.technosphere_matrix, self.demand_array)
         if self.solver_results[1] not in {1, 2}:
             warnings.warn(
                 "No suitable solution found - supply array is probably nonsense",
-                NoSolutionFound
+                NoSolutionFound,
             )
         return self.solver_results[0]
 
-    def decompose_technosphere(self):
+    def decompose_technosphere(self) -> None:
         raise NotImplementedError("Can't decompose rectangular technosphere")
